install_panic_hook_with_abort

Function install_panic_hook_with_abort 

pub fn install_panic_hook_with_abort(client: Arc<BugwatchClient>)
Install a panic hook that captures panics and then aborts the process.

This is useful for applications that need to ensure panics are always captured before the process exits.